@@ -192,7 +192,7 @@ def serve(args) -> None:
     Serve current dir as as git daemon
     @argument --ip, help=IP addr
     @argument --port, help=Port
-    @argument --daemon, help=Run as daemon, default=1
+    @argument --daemon, help=Run as daemon, default=0
     @argument --pidfile, help=Pid file, default=./git-daemon.pid
     @argument --stop, default=0, help=stop git daemon
     '''
@@ -205,10 +205,11 @@ def serve(args) -> None:
     util.info('git daemon will listen on %s:%s/.git' % (ip, port))
     cmd = 'git daemon --reuseaddr --base-path=. --export-all \
     --verbose --enable=receive-pack --port=%s --listen=%s --pid-file=./git-daemon.pid' % (port, ip)
-    local(cmd, block=bool(int(args.daemon)))
+    local(cmd, block=not bool(int(args.daemon)))
 
 
 @as_command
+@ignore
 def stop_serve(args) -> None:
     '''
     Stop git serve
@@ -238,7 +239,7 @@ def main():
     pattern.update({k: v for k, v in globals().items() if k in __all__})
     util.info('Using %spython' % (prefix and 'dfault'))
     try:
-        cli_main(argv=sys.argv, pattern=pattern, allow=('stackfile', 'execfile'))
+        cli_main(argv=sys.argv, pattern=pattern, allow=('stackfile', ))
     except Exception as ex:
         util.error("Exception <%s>, Traceback:" % str(ex))
         util.error(traceback.format_exc())
